@@ -1,15 +1,13 @@
 from importlib import import_module
 from pkgutil import iter_modules
 from functools import lru_cache
-from importlib.util import spec_from_file_location
-from importlib.util import module_from_spec
 
 from pybrary.func import fqn
 from pybrary.files import find
+from pybrary.modules import load
 
 from . import debug, error
 import setux.core
-from .distro import Distro
 
 
 @lru_cache()
@@ -17,26 +15,26 @@ def get_modules(ns):
     debug(f'{ns.__name__}')
     path, name = ns.__path__, ns.__name__ + '.'
     try:
-        # namespace
-        found = list()
-        for pth in path._path:
-            debug(f'    {pth}')
-            for fil in find(pth, r'\.py$'):
-                if fil.name=='__init__.py':
-                    error(f' ! __init__ in ns {pth}')
-                    break
-                nam = name+fil.stem
-                spec = spec_from_file_location(nam, fil)
-                mod = module_from_spec(spec)
-                spec.loader.exec_module(mod)
-                found.append((nam, mod))
-        return found
+        fil = None
+        if hasattr(path, '_path'):                   # namespace
+            found = list()
+            for pth in path._path:
+                debug(f'    {pth}')
+                for fil in find(pth, r'\.py$'):
+                    if fil.name=='__init__.py':
+                        error(f' ! __init__ in ns {pth}')
+                        return
+                    nam = name+fil.stem
+                    mod = load(nam, fil)
+                    found.append((nam, mod))
+            return found
+        else:                                        # package
+            return [
+                (name, import_module(name))
+                for finder, name, _ispkg in iter_modules(path, name)
+            ]
     except Exception as x:
-        # package
-        return [
-            (name, import_module(name))
-            for finder, name, _ispkg in iter_modules(path, name)
-        ]
+        error(f'\n ! {fil or name}\n ! {x}\n')
 
 
 def get_raw_plugins(ns, cls):
@@ -59,8 +57,8 @@ def get_plugins(ns, cls):
 
 
 class Plugins:
-    def __init__(self, target, Base, ns):
-        self.target = target
+    def __init__(self, distro, Base, ns):
+        self.distro = distro
         self.Base = Base
         self.ns = ns
         self.items = dict()
@@ -84,15 +82,11 @@ class Plugins:
             debug('%s registred', fqn(mod))
 
 
-class Managers(Plugins):
-    pass
-
-
 class Distros(Plugins):
     def sort(self):
         def sort_key(item):
             name, cls = item
-            return len(Distro.distro_lineage(cls))
+            return len(cls.distro_lineage(cls))
 
         self.items = dict(
             item
@@ -103,9 +97,9 @@ class Distros(Plugins):
         )
 
 
-class Modules(Plugins):
+class DistroPlugin(Plugins):
     def parse(self, mod, plg, plugin):
-        lineage = self.target.distro.lineage
+        lineage = self.distro.lineage
         if plg in lineage:
             name = '.'.join(mod.split('.')[2:])
             old = self.items.get(mod)
@@ -117,3 +111,11 @@ class Modules(Plugins):
             else:
                 return name, plugin
         return None, None
+
+
+class Modules(DistroPlugin): pass
+
+
+class Managers(DistroPlugin): pass
+
+
